DENOFO questionnaire
====================

The DENOFO questionnaire is a set of questions that guide the annotation process 
of de novo genes. This tool is designed to ensure that all relevant information 
is captured and that the annotation is consistent across different studies.

There are two interfaces for the questionnaire: a command-line interface (CLI) 
and a graphical user interface (GUI).


Command-line interface (CLI)
----------------------------

.. automodule:: denofo.questionnaire.questionnaire_cli
    :members:


Graphical user interface (GUI)
------------------------------

.. automodule:: denofo.questionnaire.questionnaire_gui
    :members:


questionnaire logic implementation
----------------------------------

.. automodule:: denofo.questionnaire.questions
    :members:

